Package {nudibranch}


Title: Colour Palettes Inspired by Sea Slugs and Nudibranchs of Sydney
Version: 0.0.1.1
Description: A collection of colour palettes derived from photographs of nudis and sea slugs I have encountered in intertidal zones and shallow rocky reefs around Sydney, Australia. Palettes can be used in base R or with 'ggplot2'.
License: MIT + file LICENSE
Imports: ggplot2
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://github.com/nikihubbard/nudibranch
BugReports: https://github.com/nikihubbard/nudibranch/issues
NeedsCompilation: no
Packaged: 2026-05-11 22:27:36 UTC; nikhu
Author: Niki Hubbard [aut, cre]
Maintainer: Niki Hubbard <nik.hubbard@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-15 20:40:09 UTC

Get a nudibranch colour palette

Description

Get a nudibranch colour palette

Usage

nudibranch_palette(name = NULL, n = NULL, type = c("discrete", "continuous"))

Arguments

name

Name of the palette (e.g. "hypselodoris"). If NULL, prints all available palette names.

n

Number of colours to return. If NULL, returns all colours.

type

Either "discrete" or "continuous".

Value

A character vector of hex colour codes.nudibranch_palette. The palette name is stored as an attribute. If name is NULL, returns a named list of all available palettes invisibly.

Examples

nudibranch_palette("hypselodoris")
nudibranch_palette("elysia", n = 3)

Nudibranch colour palettes

Description

A named list of colour palettes inspired by nudibranchs and sea slugs photographed in Australian waters.

Usage

nudibranch_palettes

Format

An object of class list of length 12.


Print a nudibranch palette

Description

Print a nudibranch palette

Usage

## S3 method for class 'nudibranch_palette'
print(x, ...)

Arguments

x

A nudibranch_palette object

...

Additional arguments (ignored)

Value

Invisibly returns x. Called for its side effect of printing the palette name and hex colour codes to the console.


ggplot2 colour scale using a nudibranch palette

Description

ggplot2 colour scale using a nudibranch palette

Usage

scale_colour_nudibranch(name, n = NULL, type = "discrete", ...)

Arguments

name

Name of the palette (e.g. "hypselodoris")

n

Number of colours. If NULL, returns all colours in the palette.

type

Either "discrete" or "continuous"

...

Additional arguments passed to ggplot2

Value

A ggplot2 scale object that can be added to a ggplot. Specifically a ScaleDiscrete object created by scale_colour_manual


ggplot2 fill scale using a nudibranch palette

Description

ggplot2 fill scale using a nudibranch palette

Usage

scale_fill_nudibranch(name, n = NULL, type = "discrete", ...)

Arguments

name

Name of the palette (e.g. "hypselodoris")

n

Number of colours. If NULL, returns all colours in the palette.

type

Either "discrete" or "continuous"

...

Additional arguments passed to ggplot2

Value

A ggplot2 scale object that can be added to a ggplot. Specifically a ScaleDiscrete object created by scale_fill_manual